Authors
=======

* Stian Soiland-Reyes <https://orcid.org/0000-0001-9842-9718>
* Bruno P. Kinoshita <https://orcid.org/0000-0001-8250-4074>

Acknowledgments
---------------

* Mark Wilkinson <https://orcid.org/0000-0001-6960-357X>
* Herbert van de Sompel <https://orcid.org/0000-0002-0715-6126>
* Finn Bacall <https://orcid.org/0000-0002-0048-3300>
* Vincent Emonet <https://orcid.org/0000-0002-1501-1082>
